﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Xml;

using MindFusion.Charting;

namespace XmlBinding
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			// load sample xml file
			XmlDocument doc = new XmlDocument();
			doc.Load("Data.xml");

			// create XML series bound to XPath expressions and add them to the chart;
			// alternatively, you could assign the XmlDocument to Chart.DataSource
			// and assign the XPath expressions to its various DataField* properties
			var series = new XmlSeries(doc, "weather-observations/product/group/obs/d[@t='tx']");
			series.Title = "maximum temperature";
			series.ToolTipsPath = "weather-observations/product/group/obs/@station";
			lineChart.Series.Add(series);

			series = new XmlSeries(doc, "weather-observations/product/group/obs/d[@t='tn']");
			series.Title = "minimum temperature";
			series.ToolTipsPath = "weather-observations/product/group/obs/@station";
			lineChart.Series.Add(series);

			// customize appearance
			lineChart.XAxis.Title = "Time";
			lineChart.YAxis.Title = "Degrees Celsius";

			lineChart.LegendHorizontalAlignment = MindFusion.Charting.Components.LayoutAlignment.Far;
			lineChart.LegendVerticalAlignment = MindFusion.Charting.Components.LayoutAlignment.Far;
			lineChart.BackColor = Color.White;

			lineChart.Theme = new Theme();
			lineChart.Theme.CommonSeriesFills = lineChart.Theme.CommonSeriesStrokes = new List<MindFusion.Drawing.Brush>
			{ 
				new MindFusion.Drawing.SolidBrush(Color.FromArgb(206, 0, 0)),
				new MindFusion.Drawing.SolidBrush(Color.FromArgb(0, 52, 102))
			};
			lineChart.Theme.CommonSeriesStrokeThicknesses = new List<double>() { 3.0 };
			lineChart.Theme.LegendBackground = new MindFusion.Drawing.SolidBrush(Color.FromArgb(240, 240, 240));
			lineChart.Theme.LegendBorderStroke = new MindFusion.Drawing.SolidBrush(Color.Black);
			lineChart.Theme.GridLineStyle = System.Drawing.Drawing2D.DashStyle.Dash;
			lineChart.GridType = GridType.Horizontal;

		}
	}
}